| _method |
str |
Specifies the method used for regression, set to “feols”. |
| _is_iv |
bool |
Indicates whether instrumental variables are used, initialized as False. |
| _Y |
np.ndarray |
The demeaned dependent variable, a two-dimensional numpy array. |
| _X |
np.ndarray |
The demeaned independent variables, a two-dimensional numpy array. |
| _X_is_empty |
bool |
Indicates whether the X array is empty. |
| _collin_tol |
float |
Tolerance level for collinearity checks. |
| _coefnames |
list |
Names of the coefficients (of the design matrix X). |
| _collin_vars |
list |
Variables identified as collinear. |
| _collin_index |
list |
Indices of collinear variables. |
| _Z |
np.ndarray |
Alias for the _X array, used for calculations. |
| _solver |
str |
The solver used for the regression. |
| _weights |
np.ndarray |
Array of weights for each observation. |
| _N |
int |
Number of observations. |
| _k |
int |
Number of independent variables (or features). |
| _support_crv3_inference |
bool |
Indicates support for CRV3 inference. |
| _data |
Any |
Data used in the regression, to be enriched outside of the class. |
| _fml |
Any |
Formula used in the regression, to be enriched outside of the class. |
| _has_fixef |
bool |
Indicates whether fixed effects are used. |
| _fixef |
Any |
Fixed effects used in the regression. |
| _icovars |
Any |
Internal covariates, to be enriched outside of the class. |
| _ssc_dict |
dict |
dictionary for sum of squares and cross products matrices. |
| _tZX |
np.ndarray |
Transpose of Z multiplied by X, set in get_fit(). |
| _tXZ |
np.ndarray |
Transpose of X multiplied by Z, set in get_fit(). |
| _tZy |
np.ndarray |
Transpose of Z multiplied by Y, set in get_fit(). |
| _tZZinv |
np.ndarray |
Inverse of the transpose of Z multiplied by Z, set in get_fit(). |
| _beta_hat |
np.ndarray |
Estimated regression coefficients. |
| _Y_hat_link |
np.ndarray |
Prediction at the level of the explanatory variable, i.e., the linear predictor X @ beta. |
| _Y_hat_response |
np.ndarray |
Prediction at the level of the response variable, i.e., the expected predictor E(Y|X). |
| _u_hat |
np.ndarray |
Residuals of the regression model. |
| _scores |
np.ndarray |
Scores used in the regression analysis. |
| _hessian |
np.ndarray |
Hessian matrix used in the regression. |
| _bread |
np.ndarray |
Bread matrix, used in calculating the variance-covariance matrix. |
| _vcov_type |
Any |
Type of variance-covariance matrix used. |
| _vcov_type_detail |
Any |
Detailed specification of the variance-covariance matrix type. |
| _is_clustered |
bool |
Indicates if clustering is used in the variance-covariance calculation. |
| _clustervar |
Any |
Variable used for clustering in the variance-covariance calculation. |
| _G |
Any |
Group information used in clustering. |
| _ssc |
Any |
Sum of squares and cross products matrix. |
| _vcov |
np.ndarray |
Variance-covariance matrix of the estimated coefficients. |
| _se |
np.ndarray |
Standard errors of the estimated coefficients. |
| _tstat |
np.ndarray |
T-statistics of the estimated coefficients. |
| _pvalue |
np.ndarray |
P-values associated with the t-statistics. |
| _conf_int |
np.ndarray |
Confidence intervals for the estimated coefficients. |
| _F_stat |
Any |
F-statistic for the model, set in get_Ftest(). |
| _fixef_dict |
dict |
dictionary containing fixed effects estimates. |
| _alpha |
pd.DataFrame |
A DataFrame with the estimated fixed effects. |
| _sumFE |
np.ndarray |
Sum of all fixed effects for each observation. |
| _rmse |
float |
Root mean squared error of the model. |
| _r2 |
float |
R-squared value of the model. |
| _r2_within |
float |
R-squared value computed on demeaned dependent variable. |
| _adj_r2 |
float |
Adjusted R-squared value of the model. |
| _adj_r2_within |
float |
Adjusted R-squared value computed on demeaned dependent variable. |
| _solver |
Literal["np.linalg.lstsq", "np.linalg.solve", "scipy.linalg.solve", |
“scipy.sparse.linalg.lsqr”, “jax”], default is “scipy.linalg.solve”. Solver to use for the estimation. |
| _demeaner_backend |
DemeanerBackendOptions |
|
| _data |
pd.DataFrame |
The data frame used in the estimation. None if arguments lean = True or store_data = False. |
| _model_name |
str |
The name of the model. Usually just the formula string. If split estimation is used, the model name will include the split variable and value. |
| _model_name_plot |
str |
The name of the model used when plotting and summarizing models. Usually identical to _model_name. This might be different when pf.summary() or pf.coefplot() are called and models with identical _model_name attributes are passed. In this case, the _model_name_plot attribute will be modified. |
| _quantile |
Optional[float] |
The quantile used for quantile regression. None if not a quantile regression. |
| # special for did |
|
|
| _res_cohort_eventtime_dict |
Optional[dict[str, Any]] |
|
| _yname |
Optional[str] |
|
| _gname |
Optional[str] |
|
| _tname |
Optional[str] |
|
| _idname |
Optional[str] |
|
| _att |
Optional[Any] |
|
| test_treatment_heterogeneity |
Callable[…, Any] |
|
| aggregate |
Callable[…, Any] |
|
| iplot_aggregate |
Callable[…, Any] |
|